si: Another round of PCS related fixes

Inside the SI1 rest_octets we will need to indicate if the ARFCN
is band 1800 or 1900. If the BTS is either 850 or 1900 we assume
we are running a PCS network, otherwise it is a DCS network.

The band indicator is not documented in GSM 04.08 but it is in the
GSM 05.14 version 6.1.0 Release 1997.
diff --git a/openbsc/src/libbsc/system_information.c b/openbsc/src/libbsc/system_information.c
index 41881d9..acf7134 100644
--- a/openbsc/src/libbsc/system_information.c
+++ b/openbsc/src/libbsc/system_information.c
@@ -58,6 +58,15 @@
 	return 0;
 }
 
+static int is_dcs_net(const struct gsm_bts *bts)
+{
+	if (bts->band == GSM_BAND_850)
+		return 0;
+	if (bts->band == GSM_BAND_1900)
+		return 0;
+	return 1;
+}
+
 static int use_arfcn(const struct gsm_bts *bts, const int bis, const int ter,
 			const int pgsm, const int arfcn)
 {
@@ -388,8 +397,11 @@
 
 	si1->rach_control = bts->si_common.rach_control;
 
-	/* SI1 Rest Octets (10.5.2.32), contains NCH position */
-	rc = rest_octets_si1(si1->rest_octets, NULL);
+	/*
+	 * SI1 Rest Octets (10.5.2.32), contains NCH position and band
+	 * indicator but that is not in the 04.08.
+	 */
+	rc = rest_octets_si1(si1->rest_octets, NULL, is_dcs_net(bts));
 
 	return sizeof(*si1) + rc;
 }